@@ -455,7 +455,7 @@ class Llama:
             output += bytes(buffer[:n])
         # NOTE: Llama1 models automatically added a space at the start of the prompt
         # this line removes a leading space if the first token is a beginning of sentence token
-        return output[1:] if len(tokens) > 0 and tokens[0] == self.token_bos() else output
+        return output
 
     def set_cache(self, cache: Optional[BaseLlamaCache]):
         """Set the cache.
